==> python-diameter-0.5.4.tar.gz: python-diameter-0.5.4/docs/api/commands/credit_control.md <==
API reference for `diameter.message.commands.credit_control`.

Diameter Credit Control Application

This module contains Credit Control Request and Answer messages, implementing
AVPs documented in `rfc8506`, `rfc5777` and `rfc6733`.

::: diameter.message.commands.credit_control.CreditControl
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false


::: diameter.message.commands.credit_control.CreditControlAnswer
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false
      show_if_no_docstring: true
      filters:
        - "!^_"
        - "!^avp_def"


::: diameter.message.commands.credit_control.CreditControlRequest
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false
      show_if_no_docstring: true
      filters:
        - "!^_"
        - "!^avp_def"


::: diameter.message.commands.credit_control.CostInformation
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.FinalUnitIndication
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.GrantedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.GsuPoolReference
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.Mscc
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.ProxyInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.RequestedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.ServiceParameterInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.SubscriptionId
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UsedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UserEquipmentInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UserEquipmentInfoExtension
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"

==> python-diameter-0.5.6.tar.gz: python-diameter-0.5.6/docs/api/commands/credit_control.md <==
---
shallow_toc: 4
---
API reference for `diameter.message.commands.credit_control`.

Diameter Credit Control Application

This module contains Credit Control Request and Answer messages, implementing
AVPs documented in `rfc8506`, `rfc5777` and `rfc6733`.

::: diameter.message.commands.credit_control.CreditControl
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false


::: diameter.message.commands.credit_control.CreditControlAnswer
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false
      show_if_no_docstring: true
      filters:
        - "!^_"
        - "!^avp_def"


::: diameter.message.commands.credit_control.CreditControlRequest
    options:
      show_root_heading: true
      show_root_full_path: false
      show_submodules: false
      show_if_no_docstring: true
      filters:
        - "!^_"
        - "!^avp_def"


::: diameter.message.commands.credit_control.CostInformation
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.FinalUnitIndication
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.GrantedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.GsuPoolReference
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.MultipleServicesCreditControl
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.ProxyInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.RequestedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.ServiceParameterInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.SubscriptionId
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UsedServiceUnit
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UserEquipmentInfo
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"


::: diameter.message.commands.credit_control.UserEquipmentInfoExtension
    options:
      show_root_heading: true
      show_root_full_path: false
      show_if_no_docstring: true
      filters:
        - "!^avp_def"
